@@ -1485,11 +1485,11 @@ def init_diagonostic():
     print ("Testing Fernet methods")
     # using prev test file
     # generating a key
-    key = cipher.generate_FerNet_key()
+    fernet_key = cipher.generate_FerNet_key()
     # encrypting the file
-    cipher.FerNet_encrypt_file("test_file.txt", key)
+    cipher.FerNet_encrypt_file("test_file.txt", key=fernet_key)
     # decrypting the file
-    cipher.FerNet_decrypt_file("test_file.txt", key)
+    cipher.FerNet_decrypt_file("test_file.txt", key=fernet_key)
     # checking if the file is decrypted
     with open("test_file.txt", "r") as f:
         assert f.read() == "Hello World"
